==> dhall-lsp-server-1.1.2-41-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-lsp-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-lsp-server
version:              1.1.2
visibility:           public
id:                   dhall-lsp-server-1.1.2-3ITwdRQHQAJ9h3q7WX3V3A
key:                  dhall-lsp-server-1.1.2-3ITwdRQHQAJ9h3q7WX3V3A
license:              MIT
copyright:            2019 panaeon
maintainer:           Gabriel Gonzalez
author:               panaeon
homepage:
    https://github.com/dhall-lang/dhall-haskell/tree/master/dhall-lsp-server#readme

synopsis:             Language Server Protocol (LSP) server for Dhall
abi:                  2b121a88628f4a9bcb782cd31c55a698
exposed:              True
exposed-modules:
    Dhall.LSP.Backend.Completion Dhall.LSP.Backend.Dhall
    Dhall.LSP.Backend.Diagnostics Dhall.LSP.Backend.Formatting
    Dhall.LSP.Backend.Freezing Dhall.LSP.Backend.Linting
    Dhall.LSP.Backend.Parsing Dhall.LSP.Backend.ToJSON
    Dhall.LSP.Backend.Typing Dhall.LSP.Handlers Dhall.LSP.Server
    Dhall.LSP.State

hidden-modules:       Paths_dhall_lsp_server Dhall.LSP.Util
import-dirs:          /usr/lib/ghc-9.0.2/site-local/dhall-lsp-server-1.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/dhall-lsp-server-1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-lsp-server
hs-libraries:         HSdhall-lsp-server-1.1.2-3ITwdRQHQAJ9h3q7WX3V3A
depends:
    aeson-2.1.1.0-8KPen6hyeogLmhemp4ZbOa
    aeson-pretty-0.8.9-HgDgW0QkNCrJG86cGxB5yu base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    data-default-0.7.1.1-BkZarJ3J3008hHF2JOuYeW
    dhall-1.41.2-5DWJo09SAu99ofZCWiUWtP
    dhall-json-1.7.11-Gr4R8VKOw7S8rV4r2Knp4L directory-1.3.6.2
    filepath-1.4.2.1 hslogger-1.3.1.0-4WaJPAY0vmV8dFDJL0jgUN
    lens-5.2-FIFCk99mBlr59mek6Z6LQh lsp-1.4.0.0-AB69ttCLMZnHPB1UqK2m1
    megaparsec-9.3.0-IsOTupFw4JPDV46Jn1LcDz mtl-2.2.2
    network-uri-2.6.4.2-Bqno6giiEJ72xMDyBU05Tf
    prettyprinter-1.7.1-1eigGMPeiKS44iOuiueNMF
    rope-utf16-splay-0.3.2.0-EhPvn6PS43vDTBqenqxTBl text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.19.1-AupS6pw9cGS61feF3nE08
    uri-encode-1.5.0.7-LmY6hnko7C58W2ZLUbxQfd

haddock-interfaces:
    /usr/share/doc/dhall-lsp-server/html/dhall-lsp-server.haddock

haddock-html:         /usr/share/doc/dhall-lsp-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-lsp-server-1.1.2-43-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-lsp-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-lsp-server
version:              1.1.2
visibility:           public
id:                   dhall-lsp-server-1.1.2-8qiOVi5PrQk5hiSXNowuab
key:                  dhall-lsp-server-1.1.2-8qiOVi5PrQk5hiSXNowuab
license:              MIT
copyright:            2019 panaeon
maintainer:           Gabriel Gonzalez
author:               panaeon
homepage:
    https://github.com/dhall-lang/dhall-haskell/tree/master/dhall-lsp-server#readme

synopsis:             Language Server Protocol (LSP) server for Dhall
abi:                  264f8c1473b256f574f7270b361693f7
exposed:              True
exposed-modules:
    Dhall.LSP.Backend.Completion Dhall.LSP.Backend.Dhall
    Dhall.LSP.Backend.Diagnostics Dhall.LSP.Backend.Formatting
    Dhall.LSP.Backend.Freezing Dhall.LSP.Backend.Linting
    Dhall.LSP.Backend.Parsing Dhall.LSP.Backend.ToJSON
    Dhall.LSP.Backend.Typing Dhall.LSP.Handlers Dhall.LSP.Server
    Dhall.LSP.State

hidden-modules:       Paths_dhall_lsp_server Dhall.LSP.Util
import-dirs:          /usr/lib/ghc-9.0.2/site-local/dhall-lsp-server-1.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/dhall-lsp-server-1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-lsp-server
hs-libraries:         HSdhall-lsp-server-1.1.2-8qiOVi5PrQk5hiSXNowuab
depends:
    aeson-2.1.1.0-89tw9TojhqC8APL5SUZBTN
    aeson-pretty-0.8.9-Cg5IJGkFCbdASo1rtWwuGk base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    data-default-0.7.1.1-BkZarJ3J3008hHF2JOuYeW
    dhall-1.41.2-7puHp0srC2tKLE9PY5jnTN
    dhall-json-1.7.11-4RtnIjHmam0H9J8WZdyAh3 directory-1.3.6.2
    filepath-1.4.2.1 hslogger-1.3.1.0-AWDCgx0i86LJ49D6Xw569J
    lens-5.2-BC5NPtPKpOcKo0BsEYg2qz lsp-1.4.0.0-KGF0EEHtIAk4Fj1A6s0sRi
    megaparsec-9.3.0-I8dZeAQ8VgBLLEuQwxM6ly mtl-2.2.2
    network-uri-2.6.4.2-jElrQg2aPRKF4i3iqt89K
    prettyprinter-1.7.1-3383T3Tmrgk5lFgxpFdYXc
    rope-utf16-splay-0.3.2.0-8SQS5u9ckibISp0rlKetFA text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.19.1-BhZsa6ockH0DcHre2yPBKc
    uri-encode-1.5.0.7-KKmijOR4V52LtW1URg0LRq

haddock-interfaces:
    /usr/share/doc/dhall-lsp-server/html/dhall-lsp-server.haddock

haddock-html:         /usr/share/doc/dhall-lsp-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
